pub enum GrammarError {
ParseError {
pos: usize,
msg: String,
},
Stuck,
UnknownRule {
rule: String,
},
RecursionLimit {
rule: String,
},
}Expand description
Errors that can occur during grammar parsing or state machine execution.
Variants
ParseError
Syntax error during GBNF grammar parsing.
Fields
Stuck
Grammar state machine reached a dead state — no valid next tokens exist.
UnknownRule
A rule reference in the grammar points to a rule that was never defined.
RecursionLimit
Recursion depth limit exceeded during grammar simulation.